#!/usr/bin/env bash

>&2 echo "DESTRUCTIVE!!! Syncing source WordPress database to destination."

source_path="/srv/www/beta.tf/${main_repo_name}"
destination_path="${project_base}"
source_domain="${main_repo_name}.beta.tf"
destination_domain="${main_repo_name}"
>&2 echo "${main_repo_name}.beta.tf"

## Exit if pipe fails ##
set -o pipefail

## Source scripts
vendor_brewpixel_barista_bin_wp_dir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

source "${vendor_brewpixel_barista_bin_wp_dir}/../../Burr/burr-dependencies.sh"
ensure_readlink_installed

if [[ "$OSTYPE" == "linux-gnu" ]]; then
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
elif [[ "$OSTYPE" == "darwin"* ]]; then
	# Mac OSX
	vendor_brewpixel_barista_bin_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(greadlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(greadlink -f $(dirname "${vendor_dir}"))
else
    # Unknown.
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
fi

## Source scripts
source "${vendor_brewpixel_barista_dir}/config.sh"
source "${vendor_brewpixel_barista_dir}/Burr/bootstrap.sh"

#source "${vendor_brewpixel_barista_dir}/../bashful/bin/bashful"

for f in $(ls "${vendor_brewpixel_barista_dir}/Burr/");
    do source "${vendor_brewpixel_barista_dir}/Burr/${f}";
done

>&2 echo "${destination_path}"
cd "${destination_path}"

# Before continuing, check that the database prefix matches source
db_prefix_source=$(ssh ${sshuser}@${sship} "cd "${source_path}" && wp db prefix")
db_prefix_destination=$(ssh ${sshuser}@${sship} "cd "${destination_path}" && wp db prefix")
>&2 echo "$db_prefix_destination"
>&2 echo "$db_prefix_source"
if [ "$db_prefix_destination" = "$db_prefix_source" ]; then
    >&2 echo "Destination and source database table prefixes match."
else
    die "Destination and source database table prefixes do not match. Please fix this so they match before attempting to synchronise them again."
fi

today=$(date +"%Y-%m-%d")

# Backup, Drop and Create destination database
ssh ${sshuser}@${sship} "cd "${destination_path}" && wp db export --single-transaction --opt --quote-names --complete-insert --compress "${destination_path}"/public_html/content/${today}-${main_repo_name}.sql && wp db reset --yes"

#eval "$(parse_yaml "${source_path}")"
#>&2 echo "Location of Source WordPress: $path"
#>&2 echo "SSH user: $sshuser"
#>&2 echo "SSH IP: $sship"
#
#eval "$(parse_yaml "${destination_path}/wp-cli.yml")"
#>&2 echo "Location of Destination WordPress: $path"

### Export source database. Import source database file into destination database ###
ssh ${sshuser}@${sship} "cd "${source_path}" && wp db export --single-transaction --opt --quote-names --complete-insert --compress - | wp db import --path="${destination_path}/public_html/wp" -"

# Search and replace source URLs to destination
ssh ${sshuser}@${sship} "cd "${destination_path}" && wp search-replace "${source_domain}" "${destination_domain}" --skip-columns=guid --all-tables
wp search-replace "www.${destination_domain}" "${destination_domain}" --skip-columns=guid --all-tables
wp search-replace "${destination_domain}/wp-content" "${destination_domain}/content" --skip-columns=guid --all-tables
wp search-replace "${destination_domain}\/wp-content" "${destination_domain}\/content" --skip-columns=guid --all-tables
wp search-replace "${destination_domain}%2Fwp-content" "${destination_domain}%2Fcontent" --skip-columns=guid --all-tables
wp search-replace 'wp-content/uploads' 'content/uploads' --skip-columns=guid --all-tables
wp search-replace 'wp-content\/uploads' 'content\/uploads' --skip-columns=guid --all-tables"

#If production
# wp option update blog_public 1
# Else
# wp option update blog_public 0

>&2 echo "Finished syncing source WordPress database to destination."
