#!/usr/bin/env bash

>&2 echo "DESTRUCTIVE!!! Syncing staging WordPress database to production."

## Exit if pipe fails ##
set -o pipefail

## Source scripts
vendor_brewpixel_barista_bin_wp_dir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

source "${vendor_brewpixel_barista_bin_wp_dir}/../../Burr/burr-dependencies.sh"
ensure_readlink_installed

if [[ "$OSTYPE" == "linux-gnu" ]]; then
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
elif [[ "$OSTYPE" == "darwin"* ]]; then
	# Mac OSX
	vendor_brewpixel_barista_bin_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(greadlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(greadlink -f $(dirname "${vendor_dir}"))
else
    # Unknown.
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
fi

## Source scripts
source "${vendor_brewpixel_barista_dir}/config.sh"
source "${vendor_brewpixel_barista_dir}/Burr/bootstrap.sh"

#source "${vendor_brewpixel_barista_dir}/../bashful/bin/bashful"

for f in $(ls "${vendor_brewpixel_barista_dir}/Burr/");
    do source "${vendor_brewpixel_barista_dir}/Burr/${f}";
done

>&2 echo "${project_base}"
cd "${project_base}"

# Before continuing, check that the database prefix matches staging
db_prefix_staging=$(ssh ${sshuser}@${sship} "cd "/srv/www/beta.tf/${main_repo_name}" && wp db prefix")
db_prefix_production=$(ssh ${sshuser}@${sship} "cd "${project_base}" && wp db prefix")
>&2 echo "$db_prefix_production"
>&2 echo "$db_prefix_staging"
if [ "$db_prefix_production" = "$db_prefix_staging" ]; then
    >&2 echo "Production and staging database table prefixes match."
else
    die "Production and staging database table prefixes do not match. Please fix this so they match before attempting to synchronise them again."
fi

today=$(date +"%Y-%m-%d")

# Backup, Drop and Create production database
ssh ${sshuser}@${sship} "cd "${project_base}" && wp db export --single-transaction --opt --quote-names --complete-insert --compress "${project_base}"/public_html/content/${today}-${main_repo_name}.sql && wp db reset --yes"

#eval "$(parse_yaml "/srv/www/beta.tf/${main_repo_name}")"
#>&2 echo "Location of Staging WordPress: $path"
#>&2 echo "SSH user: $sshuser"
#>&2 echo "SSH IP: $sship"
#
#eval "$(parse_yaml "${project_base}/wp-cli.yml")"
#>&2 echo "Location of Production WordPress: $path"

### Export staging database. Import staging database file into production database ###
ssh ${sshuser}@${sship} "cd "/srv/www/beta.tf/${main_repo_name}" && wp db export --single-transaction --opt --quote-names --complete-insert --compress - | wp db import --path="${project_base}/public_html/wp" -"

# Search and replace staging URLs to production
ssh ${sshuser}@${sship} "cd "${project_base}" && wp search-replace "${main_repo_name}.beta.tf" "${main_repo_name}" --skip-columns=guid --all-tables
wp search-replace "www.${main_repo_name}" "${main_repo_name}" --skip-columns=guid --all-tables
wp search-replace "${main_repo_name}/wp-content" "${main_repo_name}/content" --skip-columns=guid --all-tables
wp search-replace "${main_repo_name}\/wp-content" "${main_repo_name}\/content" --skip-columns=guid --all-tables
wp search-replace "${main_repo_name}%2Fwp-content" "${main_repo_name}%2Fcontent" --skip-columns=guid --all-tables
wp search-replace 'wp-content/uploads' 'content/uploads' --skip-columns=guid --all-tables
wp search-replace 'wp-content\/uploads' 'content\/uploads' --skip-columns=guid --all-tables
wp option update blog_public 1"

>&2 echo "Finished syncing staging WordPress database to production."
